@@ -91,10 +91,10 @@ void ButtonGrid::buildRadicalButtons()
     RadicalButton *button = new RadicalButton( *it, this );
     grid->addWidget( button, row_index++, column_index );
     //Bind slots/signals for this button
-    connect( button, SIGNAL(userClicked(QString,RadicalButton::ButtonStatus)),
-               this,   SLOT(radicalClicked(QString,RadicalButton::ButtonStatus)) );
-    connect(   this, SIGNAL(clearButtonSelections()),
-             button,   SLOT(resetButton()) );
+    connect( button, &RadicalButton::userClicked,
+               this,   &ButtonGrid::radicalClicked );
+    connect(   this, &ButtonGrid::clearButtonSelections,
+             button,   &RadicalButton::resetButton );
 
     //Add this button to our list
     m_buttons.insert( *it, button );
@@ -173,13 +173,13 @@ void ButtonGrid::updateButtons()
 
   //Convert to a list, sort, and tell the world!
   QList<Kanji> kanjiList = kanjiSet.toList();
-  qSort( kanjiList );
+  std::sort(kanjiList.begin(), kanjiList.end());
   emit possibleKanji( kanjiList );
 
   //Do the announcement of the selected radical list
   QStringList radicalList( m_selectedRadicals.toList() );
   emit signalChangeStatusbar( i18n( "Selected Radicals: " )
-                              + radicalList.join( ", " ) );
+                              + radicalList.join( QStringLiteral(", ") ) );
 
   //Now figure out what our remaining radical possibilities are
   QSet<QString> remainingRadicals = m_radicalInfo->radicalsInKanji( kanjiSet );
